@@ -1,7 +1,10 @@
 """
 Settings frame class for PyGPSClient application.
 
-This handles the settings/configuration panel.
+This handles the settings/configuration panel. It references
+the common SerialConfigFrame utility class for serial port settings.
+
+Exposes the various settings as properties.
 
 Created on 12 Sep 2020
 
@@ -30,7 +33,7 @@ from tkinter import (
 )
 
 from PIL import ImageTk, Image
-from common.serialconfig_frame import SerialConfigFrame
+from .serialconfig_frame import SerialConfigFrame
 from .globals import (
     ENTCOL,
     DDD,
@@ -53,7 +56,7 @@ from .globals import (
     UBX_PROTOCOL,
     MIXED_PROTOCOL,
     KNOWNGPS,
-    BAUDRATES,
+    BPSRATES,
 )
 from .strings import (
     LBLUBXCONFIG,
@@ -66,6 +69,7 @@ from .strings import (
 )
 
 TIMEOUTS = (
+    "0.1",
     "0.2",
     "1",
     "2",
@@ -74,13 +78,12 @@ TIMEOUTS = (
     "20",
     "None",
     "0",
-    "0.1",
 )
 
 
 class SettingsFrame(Frame):
     """
-    Frame inheritance class for application settings and controls.
+    Settings frame class.
     """
 
     def __init__(self, app, *args, **kwargs):
@@ -96,7 +99,6 @@ class SettingsFrame(Frame):
         self.__master = self.__app.get_master()  # Reference to root class (Tk)
         Frame.__init__(self, self.__master, *args, **kwargs)
 
-        self._settings = {}
         self._protocol = IntVar()
         self._raw = IntVar()
         self._autoscroll = IntVar()
@@ -106,10 +108,12 @@ class SettingsFrame(Frame):
         self._units = StringVar()
         self._format = StringVar()
         self._datalog = IntVar()
+        self._logformat = StringVar()
         self._record_track = IntVar()
         self._show_zerosig = IntVar()
         self._show_legend = IntVar()
         self._validsettings = True
+        self._in_filepath = None
         self._logpath = None
         self._trackpath = None
         self._img_conn = ImageTk.PhotoImage(Image.open(ICON_CONN))
@@ -134,7 +138,7 @@ class SettingsFrame(Frame):
 
         # serial port configuration panel
         self._frm_serial = SerialConfigFrame(
-            self, preselect=KNOWNGPS, timeouts=TIMEOUTS, baudrates=BAUDRATES
+            self, preselect=KNOWNGPS, timeouts=TIMEOUTS, bpsrates=BPSRATES
         )
 
         # connection buttons
@@ -218,7 +222,7 @@ class SettingsFrame(Frame):
         )
         self._chk_webmap = Checkbutton(
             self._frm_options,
-            text="Web Map  Zoom",
+            text="Web Map    Zoom",
             variable=self._webmap,
             command=lambda: self._on_webmap(),
         )
@@ -243,6 +247,15 @@ class SettingsFrame(Frame):
             variable=self._datalog,
             command=lambda: self._on_data_log(),
         )
+        self._spn_datalog = Spinbox(
+            self._frm_options,
+            values=("Raw", "Parsed", "Both"),
+            width=7,
+            readonlybackground=ENTCOL,
+            wrap=True,
+            textvariable=self._logformat,
+            state=READONLY,
+        )
         self._chk_recordtrack = Checkbutton(
             self._frm_options,
             text=LBLTRACKRECORD,
@@ -304,15 +317,16 @@ class SettingsFrame(Frame):
             column=1, row=6, columnspan=2, padx=3, pady=3, sticky=(W)
         )
         self._chk_datalog.grid(column=0, row=7, padx=3, pady=3, sticky=(W))
+        self._spn_datalog.grid(column=1, row=7, padx=3, pady=3, sticky=(W))
         self._chk_recordtrack.grid(
-            column=1, row=7, columnspan=2, padx=3, pady=3, sticky=(W)
+            column=0, row=8, columnspan=2, padx=3, pady=3, sticky=(W)
         )
 
         ttk.Separator(self._frm_options).grid(
-            column=0, row=8, columnspan=4, padx=3, pady=3, sticky=(W, E)
+            column=0, row=9, columnspan=4, padx=3, pady=3, sticky=(W, E)
         )
-        self._lbl_ubxconfig.grid(column=0, row=9, padx=3, pady=3, sticky=(W))
-        self._btn_ubxconfig.grid(column=1, row=9, padx=3, pady=3, sticky=(W))
+        self._lbl_ubxconfig.grid(column=0, row=10, padx=3, pady=3, sticky=(W))
+        self._btn_ubxconfig.grid(column=1, row=10, padx=3, pady=3, sticky=(W))
 
     def _on_ubx_config(self, *args, **kwargs):  # pylint: disable=unused-argument
         """
@@ -369,8 +383,8 @@ class SettingsFrame(Frame):
         Start data file streamer
         """
 
-        self._logpath = self.__app.file_handler.open_logfile_input()
-        if self._logpath is not None:
+        self._in_filepath = self.__app.file_handler.open_infile()
+        if self._in_filepath is not None:
             self.__app.set_status("")
             self.__app.serial_handler.connect_file()
 
@@ -392,17 +406,18 @@ class SettingsFrame(Frame):
         self._datalog.set(False)
         self._record_track.set(False)
 
-    def set_controls(self, status: int):
+    def enable_controls(self, status: int):
         """
-        ...for the heart of the sun.
-        Public method to enable and disable serial port controls
-        depending on connection status.
+        Public method to enable and disable those controls
+        which depend on connection status.
 
-        :param int status: connection status as integer (0,1,2)
+        :param int status: connection status as integer
+               (0=Disconnected, 1=Connected to serial,
+               2=Connected to file, 3=No serial ports available)
 
         """
 
-        self._frm_serial.set_controls(status)
+        self._frm_serial.set_status(status)
 
         self._btn_connect.config(
             state=(
@@ -417,6 +432,11 @@ class SettingsFrame(Frame):
                 DISABLED if status in (CONNECTED, CONNECTED_FILE, NOPORTS) else NORMAL
             )
         )
+        self._spn_datalog.config(
+            state=(
+                DISABLED if status in (CONNECTED, CONNECTED_FILE, NOPORTS) else READONLY
+            )
+        )
         self._chk_recordtrack.config(
             state=(DISABLED if status in (CONNECTED, CONNECTED_FILE) else NORMAL)
         )
@@ -439,42 +459,6 @@ class SettingsFrame(Frame):
             ),
         )
 
-    def get_settings(self) -> dict:
-        """
-        Public method returns all settings as a dict.
-
-        :return: current settings
-        :rtype: dict
-
-        """
-
-        self._settings["noports"] = self._frm_serial.noports
-        self._settings["port"] = self._frm_serial.port
-        self._settings["port_desc"] = self._frm_serial.port_desc
-        self._settings["baudrate"] = self._frm_serial.baudrate
-        self._settings["databits"] = self._frm_serial.databits
-        self._settings["stopbits"] = self._frm_serial.stopbits
-        self._settings["parity"] = self._frm_serial.parity
-        self._settings["rtscts"] = self._frm_serial.rtscts
-        self._settings["xonxoff"] = self._frm_serial.xonxoff
-        self._settings["timeout"] = self._frm_serial.timeout
-
-        self._settings["protocol"] = self._protocol.get()
-        self._settings["raw"] = self._raw.get()
-        self._settings["autoscroll"] = self._autoscroll.get()
-        self._settings["maxlines"] = self._maxlines.get()
-        self._settings["webmap"] = self._webmap.get()
-        self._settings["mapzoom"] = self._mapzoom.get()
-        self._settings["units"] = self._units.get()
-        self._settings["format"] = self._format.get()
-        self._settings["logpath"] = self._logpath
-        self._settings["datalogging"] = self._datalog.get()
-        self._settings["recordtrack"] = self._record_track.get()
-        self._settings["zerosignal"] = self._show_zerosig.get()
-        self._settings["graphlegend"] = self._show_legend.get()
-
-        return self._settings
-
     def get_size(self) -> (int, int):
         """
         Get current frame size.
@@ -486,3 +470,180 @@ class SettingsFrame(Frame):
 
         self.update_idletasks()  # Make sure we know about any resizing
         return (self.winfo_width(), self.winfo_height())
+
+    def serial_settings(self) -> Frame:
+        """
+        Return reference to common serial configuration panel
+
+        :return: reference to serial form
+        :rtype: Frame
+        """
+
+        return self._frm_serial
+
+    @property
+    def protocol(self) -> int:
+        """
+        Getter for displayed protocols
+
+        :return: protocol displayed (0=NMEA, 1=UBX, 2=BOTH)
+        :rtype: int
+        """
+
+        return self._protocol.get()
+
+    @property
+    def raw(self) -> int:
+        """
+        Getter for console display format
+
+        :return: display format (0 - parsed, 1 = raw)
+        :rtype: int
+        """
+
+        return self._raw.get()
+
+    @property
+    def autoscroll(self) -> int:
+        """
+        Getter for autoscroll flag
+
+        :return: scroll setting (0 = no scroll, 1 = auto)
+        :rtype: int
+        """
+
+        return self._autoscroll.get()
+
+    @property
+    def maxlines(self) -> int:
+        """
+        Getter for max console display lines
+
+        :return: max lines in console display (default=300)
+        :rtype: int
+        """
+
+        return self._maxlines.get()
+
+    @property
+    def webmap(self) -> int:
+        """
+        Getter for webmap flag
+
+        :return: map type (0 = static map, 1 = dynamic web map)
+        :rtype: int
+        """
+
+        return self._webmap.get()
+
+    @property
+    def mapzoom(self) -> int:
+        """
+        Getter for webmap zoom level
+
+        :return: webmap zoom level (1-20)
+        :rtype: int
+        """
+
+        return self._mapzoom.get()
+
+    @property
+    def units(self) -> int:
+        """
+        Getter for display units
+
+        :return: "UMM" = metric m/s, "UMK" = metric kmph,
+                 "UI" = imperial mph, "UIK" = imperial knots
+        :rtype: int
+        """
+
+        return self._units.get()
+
+    @property
+    def format(self) -> str:
+        """
+        Getter for degrees format
+
+        :return: "DD.D" = decimal degrees, "DM.M" = degrees, decimal minutes,
+                 "D.M.S" = degrees, minutes, seconds
+        :rtype: str
+        """
+
+        return self._format.get()
+
+    @property
+    def infilepath(self) -> str:
+        """
+        Getter for input file path
+
+        :return: input file path
+        :rtype: str
+        """
+
+        return self._in_filepath
+
+    @property
+    def outfilepath(self) -> str:
+        """
+        Getter for output file path
+
+        :return: output file path
+        :rtype: str
+        """
+
+        return self._logpath
+
+    @property
+    def datalogging(self) -> int:
+        """
+        Getter for datalogging flag
+
+        :return: 0 = no log, 1 = record datalog
+        :rtype: int
+        """
+
+        return self._datalog.get()
+
+    @property
+    def logformat(self) -> str:
+        """
+        Getter for datalogging format
+
+        :return: "Raw", "Parsed", "Both"
+        :rtype: str
+        """
+
+        return self._logformat.get()
+
+    @property
+    def record_track(self) -> int:
+        """
+        Getter for record track flag
+
+        :return: 0 = no track, 1 = record track
+        :rtype: int
+        """
+
+        return self._record_track.get()
+
+    @property
+    def show_zero(self) -> int:
+        """
+        Getter for zero signal flag
+
+        :return: 0 = exclude, 1 = include
+        :rtype: int
+        """
+
+        return self._show_zerosig.get()
+
+    @property
+    def show_legend(self) -> int:
+        """
+        Getter for graph legend flag
+
+        :return: 0 = hide, 1 = show
+        :rtype: int
+        """
+
+        return self._show_legend.get()
