@@ -3,7 +3,9 @@ UBX Configuration widget for CFG-VAL commands
 
 Created on 22 Dec 2020
 
-@author: semuadmin
+:author: semuadmin
+:copyright: SEMU Consulting © 2020
+:license: BSD 3-Clause
 """
 # pylint: disable=invalid-name, too-many-instance-attributes, too-many-ancestors
 
@@ -25,6 +27,7 @@ from tkinter import (
     LEFT,
     VERTICAL,
     HORIZONTAL,
+    NORMAL,
 )
 from PIL import ImageTk, Image
 from pyubx2 import UBXMessage, UBX_CONFIG_DATABASE
@@ -94,8 +97,10 @@ class UBX_CFGVAL_Frame(Frame):
         """
         Constructor.
 
-        :param object app: reference to main tkinter application
-        :param frame container: container frame
+        :param Frame app: reference to main tkinter application
+        :param Frame container: reference to container frame (config-dialog)
+        :param args: optional args to pass to Frame parent class
+        :param kwargs: optional kwargs to pass to Frame parent class
         """
 
         self.__app = app  # Reference to main application class
@@ -120,7 +125,7 @@ class UBX_CFGVAL_Frame(Frame):
         self._body()
         self._do_layout()
         self._attach_events()
-        self._reset()
+        self.reset()
 
     def _body(self):
         """
@@ -204,7 +209,14 @@ class UBX_CFGVAL_Frame(Frame):
             readonlybackground=ENTCOL,
         )
         self._lbl_val = Label(self, text="Value")
-        self._ent_val = Entry(self, textvariable=self._cfgval, bg=ENTCOL)
+        self._ent_val = Entry(
+            self,
+            textvariable=self._cfgval,
+            readonlybackground=ENTCOL,
+            fg=INFCOL,
+            state=READONLY,
+            relief="sunken",
+        )
 
         self._lbl_send_command = Label(self)
         self._btn_send_command = Button(
@@ -230,9 +242,9 @@ class UBX_CFGVAL_Frame(Frame):
         )
         self._scr_parmv.grid(column=4, row=2, rowspan=5, sticky=(N, S, E))
         self._scr_parmh.grid(column=1, row=7, columnspan=4, sticky=(W, E))
-        self._rad_cfgset.grid(column=0, row=8, padx=3, pady=0, sticky=(W))
-        self._rad_cfgdel.grid(column=0, row=9, padx=3, pady=0, sticky=(W))
-        self._rad_cfgget.grid(column=0, row=10, padx=3, pady=0, sticky=(W))
+        self._rad_cfgget.grid(column=0, row=8, padx=3, pady=0, sticky=(W))
+        self._rad_cfgset.grid(column=0, row=9, padx=3, pady=0, sticky=(W))
+        self._rad_cfgdel.grid(column=0, row=10, padx=3, pady=0, sticky=(W))
         self._lbl_key.grid(column=1, row=8, padx=3, pady=0, sticky=(E))
         self._lbl_keyid.grid(column=2, row=8, padx=3, pady=0, sticky=(W))
         self._lbl_type.grid(column=3, row=8, padx=3, pady=0, sticky=(E))
@@ -265,8 +277,9 @@ class UBX_CFGVAL_Frame(Frame):
 
         self._lbx_cat.bind("<<ListboxSelect>>", self._on_select_cat)
         self._lbx_parm.bind("<<ListboxSelect>>", self._on_select_parm)
+        self._cfgmode.trace_add("write", self._on_select_mode)
 
-    def _reset(self):
+    def reset(self):
         """
         Reset panel.
         """
@@ -275,6 +288,16 @@ class UBX_CFGVAL_Frame(Frame):
             self._lbx_cat.insert(i, cat)
         self._cfgmode.set(2)
 
+    def _on_select_mode(self, *args, **kwargs):  # pylint: disable=unused-argument
+        """
+        Mode has been selected.
+        """
+
+        if self._cfgmode.get() == VALSET:
+            self._ent_val.config(state=NORMAL, bg=ENTCOL, fg="Black")
+        else:
+            self._ent_val.config(state=READONLY, readonlybackground=ENTCOL, fg=INFCOL)
+
     def _on_select_cat(self, *args, **kwargs):  # pylint: disable=unused-argument
         """
         Configuration category has been selected.
@@ -291,10 +314,11 @@ class UBX_CFGVAL_Frame(Frame):
             if self._cfgval_cat in keyname:
                 self._lbx_parm.insert(idx, keyname)
                 idx += 1
+        self._cfgval.set("")
 
     def _on_select_parm(self, *args, **kwargs):  # pylint: disable=unused-argument
         """
-        Configuration parameter has been selected.
+        Configuration parameter (keyname) has been selected.
         """
 
         idx = self._lbx_parm.curselection()
@@ -303,6 +327,7 @@ class UBX_CFGVAL_Frame(Frame):
         (keyid, att) = UBXMessage.cfgname2key(self._cfgval_keyname)
         self._cfgkeyid.set(hex(keyid))
         self._cfgatt.set(att)
+        self._cfgval.set("")
 
     def _on_send_config(self, *args, **kwargs):  # pylint: disable=unused-argument
         """
@@ -321,8 +346,8 @@ class UBX_CFGVAL_Frame(Frame):
         """
         Send a CFG-VALSET message.
 
-        :return valid entry flag
-        :rtype bool
+        :return: valid entry flag
+        :rtype: bool
         """
 
         valid_entry = True
@@ -433,6 +458,9 @@ class UBX_CFGVAL_Frame(Frame):
     def update_status(self, cfgtype, **kwargs):  # pylint: disable=unused-argument
         """
         Update pending confirmation status.
+
+        :param str cfgtype: identity of UBX message containing config info
+        :param kwargs: status keywords and values from UBX config message
         """
 
         if cfgtype == "CFG-VALGET":
